@@ -31,14 +31,14 @@ def yes_text():
     return Yes_text
 
 def read_from_file():
-    with open('APPLET.txt') as file:
+    with open('/Applications/Apple\ Swift\ 0.5.8/swift\ apple/swift_apple/APPLET.txt') as file:
         for line in file:
             line = line.rstrip('\n')
             condition,solution = line.split('/')
             the_physical_condition[condition] = solution
 
 def write_to_file(solution_name,condition_name):
-    with open('APPLET.txt','a')as file:
+    with open('/Applications/Apple\ Swift\ 0.5.8/swift\ apple/swift_apple/APPLET.txt','a')as file:
         file.write('\n'+ solution_name + '/' + condition_name)
 
 the_physical_condition={}
